@@ -37,8 +37,8 @@ BayesianNormal <- function(times, X, model = c("OU", "CIR"), prior, start, rando
             
             help <- numeric(M)
             for (i in 1:M) {
-                help[i] <- sum(phi[i, 2]/(1 - exp(-2 * phi[i, 2] * delta)) * (X[i, -1] - phi[i, 1]/phi[i, 2] - (X[i, -N] - phi[i, 1]/phi[i, 
-                  2]) * exp(-phi[i, 2] * delta))^2)
+                help[i] <- sum(phi[i, 2]/(1 - exp(-2 * phi[i, 2] * delta)) * (X[i, -1] - phi[i, 1]/phi[i, 2] - 
+                  (X[i, -N] - phi[i, 1]/phi[i, 2]) * exp(-phi[i, 2] * delta))^2)
             }
             betaPost <- prior$beta.sigma + sum(help)
             1/rgamma(1, alphaPost, betaPost)
@@ -46,15 +46,17 @@ BayesianNormal <- function(times, X, model = c("OU", "CIR"), prior, start, rando
     } else {
         likeli <- dcCIR2
         postSigma <- function(phi, sigmaOld = 1, propSdSigma2 = NULL) {
-            # alphaPost <- prior$alpha.sigma + M*(N-1)/2 help <- numeric(M) for (i in 1:M) { help[i] <- sum((X[i,-1] - X[i,-N] - b(phi[i, ],
-            # times[-N], X[i,-N]) * delta)^2/ (X[i,-N] * delta)) } betaPost <- prior$beta.sigma + sum(help)/2 return(1/rgamma(1, alphaPost,
-            # betaPost))
+            # alphaPost <- prior$alpha.sigma + M*(N-1)/2 help <- numeric(M) for (i in 1:M) { help[i] <- sum((X[i,-1] -
+            # X[i,-N] - b(phi[i, ], times[-N], X[i,-N]) * delta)^2/ (X[i,-N] * delta)) } betaPost <- prior$beta.sigma +
+            # sum(help)/2 return(1/rgamma(1, alphaPost, betaPost))
             
             sigma_drawn <- rnorm(1, sqrt(sigmaOld), propSdSigma2)^2
-            ratio <- dgamma(1/sigma_drawn, prior$alpha.sigma, prior$beta.sigma)/dgamma(1/sigmaOld, prior$alpha.sigma, prior$beta.sigma)  # prior ratio
+            ratio <- dgamma(1/sigma_drawn, prior$alpha.sigma, prior$beta.sigma)/dgamma(1/sigmaOld, prior$alpha.sigma, 
+                prior$beta.sigma)  # prior ratio
             ratio <- ratio * sqrt(sigma_drawn)/sqrt(sigmaOld)  # proposal ratio
             he <- sapply(1:M, function(i) {
-                prod(dcCIR2(X[i, -1], delta, X[i, -N], c(phi[i, ], sqrt(sigma_drawn)))/dcCIR2(X[i, -1], delta, X[i, -N], c(phi[i, ], sqrt(sigmaOld))))
+                prod(dcCIR2(X[i, -1], delta, X[i, -N], c(phi[i, ], sqrt(sigma_drawn)))/dcCIR2(X[i, -1], delta, 
+                  X[i, -N], c(phi[i, ], sqrt(sigmaOld))))
             })
             ratio <- ratio * prod(he)
             if (is.na(ratio)) 
@@ -75,9 +77,10 @@ BayesianNormal <- function(times, X, model = c("OU", "CIR"), prior, start, rando
                 phi[k] <- phi_out[k] + rnorm(1, 0, propSdPhi[k])
                 ratio <- prod(dnorm(phi, mu, sqrt(Omega))/dnorm(phi_out, mu, sqrt(Omega)))
                 
-                ratio <- ratio * prod(likeli(Xj[-1], delta, Xj[-N], c(phi, sqrt(sigma)))/likeli(Xj[-1], delta, Xj[-N], c(phi_out, sqrt(sigma))))
-                # ratio <- ratio * prod(dnorm(Xj[-1], Xj[-N] + b(phi, times[-N], Xj[-N]) * delta, sqrt(sigma * Xj[-N] * delta))/ dnorm(Xj[-1],Xj[-N] +
-                # b(phi_out, times[-N], Xj[-N]) * delta, sqrt(sigma * Xj[-N] * delta)))
+                ratio <- ratio * prod(likeli(Xj[-1], delta, Xj[-N], c(phi, sqrt(sigma)))/likeli(Xj[-1], delta, 
+                  Xj[-N], c(phi_out, sqrt(sigma))))
+                # ratio <- ratio * prod(dnorm(Xj[-1], Xj[-N] + b(phi, times[-N], Xj[-N]) * delta, sqrt(sigma * Xj[-N] *
+                # delta))/ dnorm(Xj[-1],Xj[-N] + b(phi_out, times[-N], Xj[-N]) * delta, sqrt(sigma * Xj[-N] * delta)))
                 if (is.na(ratio)) {
                   ratio <- 0
                 }
@@ -116,9 +119,10 @@ BayesianNormal <- function(times, X, model = c("OU", "CIR"), prior, start, rando
             phi <- lastPhi
             phi[random] <- phi[random] + rnorm(1, 0, propSdRandom)
             ratio <- dnorm(phi[random], mu, sqrt(Omega))/dnorm(phi_out[random], mu, sqrt(Omega))
-            ratio <- ratio * prod(likeli(Xj[-1], delta, Xj[-N], c(phi, sqrt(sigma)))/likeli(Xj[-1], delta, Xj[-N], c(phi_out, sqrt(sigma))))
-            # ratio <- ratio * prod(dnorm(Xj[-1], Xj[-N] + b(phi, times[-N], Xj[-N]) * delta, sqrt(sigma * Xj[-N] * delta))/ dnorm(Xj[-1], Xj[-N]
-            # + b(phi_out, times[-N], Xj[-N]) * delta, sqrt(sigma * Xj[-N] * delta)))
+            ratio <- ratio * prod(likeli(Xj[-1], delta, Xj[-N], c(phi, sqrt(sigma)))/likeli(Xj[-1], delta, Xj[-N], 
+                c(phi_out, sqrt(sigma))))
+            # ratio <- ratio * prod(dnorm(Xj[-1], Xj[-N] + b(phi, times[-N], Xj[-N]) * delta, sqrt(sigma * Xj[-N] *
+            # delta))/ dnorm(Xj[-1], Xj[-N] + b(phi_out, times[-N], Xj[-N]) * delta, sqrt(sigma * Xj[-N] * delta)))
             if (is.na(ratio)) {
                 ratio <- 0
             }
@@ -149,8 +153,8 @@ BayesianNormal <- function(times, X, model = c("OU", "CIR"), prior, start, rando
                 beta_drawn <- beta + rnorm(1, 0, propSdFixed)
                 ratio <- dnorm(beta_drawn, prior$m[2], prior$v[2])/dnorm(beta, prior$m[2], prior$v[2])
                 he <- sapply(1:M, function(i) {
-                  prod(likeli(X[i, -1], delta, X[i, -N], c(lastRandom[i], beta_drawn, sqrt(sigma)))/likeli(X[i, -1], delta, X[i, -N], 
-                    c(lastRandom[i], beta, sqrt(sigma))))
+                  prod(likeli(X[i, -1], delta, X[i, -N], c(lastRandom[i], beta_drawn, sqrt(sigma)))/likeli(X[i, 
+                    -1], delta, X[i, -N], c(lastRandom[i], beta, sqrt(sigma))))
                 })
                 ratio <- ratio * prod(he)
                 if (is.na(ratio)) {
@@ -177,12 +181,12 @@ BayesianNormal <- function(times, X, model = c("OU", "CIR"), prior, start, rando
                 alpha_drawn <- alpha + rnorm(1, 0, propSdFixed)
                 ratio <- dnorm(alpha_drawn, prior$m[1], prior$v[1])/dnorm(alpha, prior$m[1], prior$v[1])
                 he <- sapply(1:M, function(i) {
-                  prod(likeli(X[i, -1], delta, X[i, -N], c(alpha_drawn, lastRandom[i], sqrt(sigma)))/likeli(X[i, -1], delta, X[i, -N], 
-                    c(alpha, lastRandom[i], sqrt(sigma))))
+                  prod(likeli(X[i, -1], delta, X[i, -N], c(alpha_drawn, lastRandom[i], sqrt(sigma)))/likeli(X[i, 
+                    -1], delta, X[i, -N], c(alpha, lastRandom[i], sqrt(sigma))))
                 })
-                # he <- sapply(1:M, function(i){ prod(dnorm(X[i,-1], X[i,-N] + b(c(alpha_drawn, lastRandom[i]), times[-N], X[i,-N]) * delta,
-                # sqrt(sigma * X[i,-N] * delta))/ dnorm(X[i,-1], X[i,-N] + b(c(alpha, lastRandom[i]), times[-N], X[i,-N]) * delta, sqrt(sigma *
-                # X[i,-N] * delta))) } )
+                # he <- sapply(1:M, function(i){ prod(dnorm(X[i,-1], X[i,-N] + b(c(alpha_drawn, lastRandom[i]), times[-N],
+                # X[i,-N]) * delta, sqrt(sigma * X[i,-N] * delta))/ dnorm(X[i,-1], X[i,-N] + b(c(alpha, lastRandom[i]),
+                # times[-N], X[i,-N]) * delta, sqrt(sigma * X[i,-N] * delta))) } )
                 ratio <- ratio * prod(he)
                 if (is.na(ratio)) {
                   ratio <- 0
@@ -259,8 +263,8 @@ BayesianNormal <- function(times, X, model = c("OU", "CIR"), prior, start, rando
                 
                 
                 if (count%%50 == 0) {
-                  propSdPhi <- c(ad.propSd_random(alpha_out[(count - 50 + 1):count, ], propSdPhi[1], count), ad.propSd(beta_out[(count - 
-                    50 + 1):count], propSdPhi[2], count/50))
+                  propSdPhi <- c(ad.propSd_random(alpha_out[(count - 50 + 1):count, ], propSdPhi[1], count), 
+                    ad.propSd(beta_out[(count - 50 + 1):count], propSdPhi[2], count/50))
                 }
                 
                 if (model == "CIR" && count%%50 == 0) {
@@ -345,8 +349,8 @@ chain2samples <- function(res, burnIn, thinning) {
     
     ind.chain <- seq(burnIn + 1, length(res@sigma2), by = thinning)
     return(new(Class = class(res), prior = res@prior, alpha = as.matrix(res@alpha[ind.chain, ]), beta = as.matrix(res@beta[ind.chain, 
-        ]), random = res@random, mu = as.matrix(res@mu[ind.chain, ]), omega = as.matrix(res@omega[ind.chain, ]), sigma2 = res@sigma2[ind.chain], 
-        model = res@model, times = res@times, X = res@X))
+        ]), random = res@random, mu = as.matrix(res@mu[ind.chain, ]), omega = as.matrix(res@omega[ind.chain, 
+        ]), sigma2 = res@sigma2[ind.chain], model = res@model, times = res@times, X = res@X))
     
 }
 
@@ -365,7 +369,8 @@ diagnostic <- function(results, random) {
         
         he2 <- apply(he1, 2, quantile, c(0.025, 0.975))
         he.mean <- apply(he1, 2, mean)
-        is.in <- (he.mean[-m] >= he2[1, -1] & he.mean[-m] <= he2[2, -1]) | (he.mean[-1] >= he2[1, -m] & he.mean[-1] <= he2[2, -m])
+        is.in <- (he.mean[-m] >= he2[1, -1] & he.mean[-m] <= he2[2, -1]) | (he.mean[-1] >= he2[1, -m] & he.mean[-1] <= 
+            he2[2, -m])
         # burnIn <- 0
         burnIn <- K
         for (i in 1:(m - 1)) {
@@ -379,9 +384,11 @@ diagnostic <- function(results, random) {
     }
     if (length(random) == 2) {
         # he <- matrix(0,5,4) he[1, ] <- raftery.diag(as.mcmc(results$mu[,1]))$resmatrix he[2, ] <-
-        # raftery.diag(as.mcmc(results$mu[,2]))$resmatrix he[3, ] <- raftery.diag(as.mcmc(results$omega[,1]))$resmatrix he[4, ] <-
-        # raftery.diag(as.mcmc(results$omega[,2]))$resmatrix he[5, ] <- raftery.diag(as.mcmc(results$sigma2))$resmatrix burnIn <- max(he[,1])
-        # thinning <- floor(length(results$sigma2)/max(he[,3]))
+        # raftery.diag(as.mcmc(results$mu[,2]))$resmatrix he[3, ] <-
+        # raftery.diag(as.mcmc(results$omega[,1]))$resmatrix he[4, ] <-
+        # raftery.diag(as.mcmc(results$omega[,2]))$resmatrix he[5, ] <-
+        # raftery.diag(as.mcmc(results$sigma2))$resmatrix burnIn <- max(he[,1]) thinning <-
+        # floor(length(results$sigma2)/max(he[,3]))
         he <- matrix(0, 5, 2)
         he[1, ] <- diagnostic.own(results$mu[, 1])
         he[2, ] <- diagnostic.own(results$mu[, 2])
@@ -393,9 +400,10 @@ diagnostic <- function(results, random) {
         
     } else {
         if (random == 1) {
-            # he <- matrix(0,4,4) he[1, ] <- raftery.diag(as.mcmc(results$mu))$resmatrix he[2, ] <- raftery.diag(as.mcmc(results$beta))$resmatrix
-            # he[3, ] <- raftery.diag(as.mcmc(results$omega))$resmatrix he[4, ] <- raftery.diag(as.mcmc(results$sigma2))$resmatrix burnIn <-
-            # max(he[,1]) thinning <- floor(length(results$sigma2)/max(he[,3]))
+            # he <- matrix(0,4,4) he[1, ] <- raftery.diag(as.mcmc(results$mu))$resmatrix he[2, ] <-
+            # raftery.diag(as.mcmc(results$beta))$resmatrix he[3, ] <- raftery.diag(as.mcmc(results$omega))$resmatrix
+            # he[4, ] <- raftery.diag(as.mcmc(results$sigma2))$resmatrix burnIn <- max(he[,1]) thinning <-
+            # floor(length(results$sigma2)/max(he[,3]))
             he <- matrix(0, 4, 2)
             he[1, ] <- diagnostic.own(results$mu)
             he[2, ] <- diagnostic.own(results$beta)
@@ -405,9 +413,10 @@ diagnostic <- function(results, random) {
             thinning <- max(he[, 2])
             
         } else {
-            # he <- matrix(0,4,4) he[1, ] <- raftery.diag(as.mcmc(results$mu))$resmatrix he[2, ] <- raftery.diag(as.mcmc(results$alpha))$resmatrix
-            # he[3, ] <- raftery.diag(as.mcmc(results$omega))$resmatrix he[4, ] <- raftery.diag(as.mcmc(results$sigma2))$resmatrix burnIn <-
-            # max(he[,1]) thinning <- floor(length(results$sigma2)/max(he[,3]))
+            # he <- matrix(0,4,4) he[1, ] <- raftery.diag(as.mcmc(results$mu))$resmatrix he[2, ] <-
+            # raftery.diag(as.mcmc(results$alpha))$resmatrix he[3, ] <- raftery.diag(as.mcmc(results$omega))$resmatrix
+            # he[4, ] <- raftery.diag(as.mcmc(results$sigma2))$resmatrix burnIn <- max(he[,1]) thinning <-
+            # floor(length(results$sigma2)/max(he[,3]))
             he <- matrix(0, 4, 2)
             he[1, ] <- diagnostic.own(results$mu)
             he[2, ] <- diagnostic.own(results$alpha)
@@ -458,7 +467,8 @@ ad.propSd <- function(chain, propSd, iteration, lower = 0.3, upper = 0.6, delta.
 #' @param delta.n function for adding/subtracting from the log propSd
 #' @references 
 #' Rosenthal, J. S. (2011). Optimal proposal distributions and adaptive MCMC. Handbook of Markov Chain Monte Carlo, 93-112.
-ad.propSd_random <- function(chain, propSd, iteration, lower = 0.3, upper = 0.6, delta.n = function(n) min(0.1, 1/sqrt(n))) {
+ad.propSd_random <- function(chain, propSd, iteration, lower = 0.3, upper = 0.6, delta.n = function(n) min(0.1, 
+    1/sqrt(n))) {
     ar <- apply(chain, 2, function(vec) length(unique(vec))/length(vec))
     lsi <- log(propSd)
     
